close all force; clear; clc
mainpath=pwd; addpath(pwd)
load('P123_Gen_Data45')

axis_vector=[0 3 -16 20];
ytick_vector=(-10:10:10);

%% Psychometric Results
denom=squeeze(sum(ind_contingency,2));
ind_pc=zeros(locations,angles,sub_tot,conditions);
for con=1:conditions
    for sub=1:sub_tot
        for loc=1:locations
            for angl=1:length(angle_mag)
                ind_pc(loc,angl,sub,con)=ind_contingency(loc,loc,angl,sub,con)./denom(loc,angl,sub,con).*100;
            end
        end
    end
end

%%
param_label={'\Delta HR'};
param=squeeze(nanmean(ind_pc,2));

delcon=param(:,:,[1 2])-param(:,:,[2 3]); % PC-PE; PE-PL
conditions=size(delcon,3);
COND={'AE','VE'};
lnstylopts={'-','-.'};
locations=size(delcon,1);
LOCS=Default_Locations;
col=hsv(locations); 
loc_order=[1 4 3 2]; % For plotting; Cued,Contra,Ipsi,Opposite
sub_tot=size(delcon,2);
ylabel_string=param_label{1};
suptitle_string=sprintf('%s - %d Subjects', ylabel_string,  sub_tot); %%%%

%%
clear p_values
for loc=1:locations
    for con=1:conditions
        p_values(loc,con)=signrank(delcon(loc,:,con));
    end
end
av_val=squeeze(nanmean(delcon,2));
sd_val=squeeze(nanstd(delcon,0,2)./sqrt(sub_tot));

[~,~,~,~,nosigpvalsind] = multiple_comparisons_correction(p_values(:),'Benjaminihochberg');
p_val_mc=p_values;
p_val_mc(nosigpvalsind)=1;

%% Plotting
figure; set(gcf,'renderer','Painters', 'Position', [100 50 450 700])
for loc=1:locations
    subplot(2,2,loc_order(loc))
    for con=1:conditions
        bar(con,av_val(loc,con),'FaceColor','white','EdgeColor',col(loc,:),'Linewidth',0.5,'LineStyle',lnstylopts{con});
        hold on;
    end
    title(sprintf('%s',LOCS{loc}))
    errorbar(1:conditions,av_val(loc,:),sd_val(loc,:),'Color',col(loc,:),'LineStyle','None','LineWidth',0.5,'CapSize',0)
    xticks(1:conditions)
    set(gca,'xticklabel',COND,'Fontsize',8)
    ylabel(ylabel_string,'FontSize',12)
    sigstar({[0.7,1.3],[1.7,2.3]},p_val_mc(loc,:))
    axis(axis_vector)
    yticks(ytick_vector)
end
suptitle(suptitle_string)
