close all force; clear; clc
mainpath=pwd; addpath(pwd)
load('P123_Gen_Data45')

ind_contingency(ind_contingency==0)=1./2*angles; % 1/2n correction
cvals=angle_mag./90;

%% Model 1
M = 4;

InputStruct.s50_init = 0.5*max(cvals)*ones(1,M);
InputStruct.del_init = 0*ones(1,M);
InputStruct.s50_Lim = [0*ones(1,M); max(cvals)*ones(1,M)];
InputStruct.del_Lim = [-1*ones(1,M); 1*ones(1,M)];

% Setting 3 criterion and 3 s50 constrains
InputStruct.Aeq = [zeros(1,3*M) 1 -1 0 0 zeros(1,M); ... % Criterion
    zeros(1,3*M) 0 1 -1 0 zeros(1,M); ...
    zeros(1,3*M) 0 0 1 -1 zeros(1,M); ...
    zeros(1,2*M) 1 -1 0 0 zeros(1,2*M); ... %Theta 50
    zeros(1,2*M) 0 1 -1 0 zeros(1,2*M); ...
    zeros(1,2*M) 0 0 1 -1 zeros(1,2*M)];

InputStruct.Beq = zeros(size(InputStruct.Aeq,1),1);

InpStructModel{1} = InputStruct;
clear InputStruct

%% Model 2:

M = 4;

InputStruct.s50_init = 0.5*max(cvals)*ones(1,M);
InputStruct.del_init = 0*ones(1,M);
InputStruct.s50_Lim = [0*ones(1,M); max(cvals)*ones(1,M)];
InputStruct.del_Lim = [-1*ones(1,M); 1*ones(1,M)];

% Setting 3 del and 3 s50 constrains
InputStruct.Aeq = [zeros(1,4*M) 1 -1 0 0; ...
    zeros(1,4*M) 0 1 -1 0; ...
    zeros(1,4*M) 0 0 1 -1; ...
    zeros(1,2*M) 1 -1 0 0 zeros(1,2*M); ...
    zeros(1,2*M) 0 1 -1 0 zeros(1,2*M); ...
    zeros(1,2*M) 0 0 1 -1 zeros(1,2*M)];

InputStruct.Beq = zeros(size(InputStruct.Aeq,1),1);

InpStructModel{2} = InputStruct;
clear InputStruct

%% Fitting
mod_names_arr = {'Model1: c\delta_i', 'Model2: c_i\delta'};
NoOfParams = [10 10]; 

tic
for con=1:conditions
    for sub=[13 21 31]%1:sub_tot
        for mod = 1:length(mod_names_arr)
            clear theta_est theta_err LLF ctable_mod ctable_fit psyc_mate d0 sivals cont
            
            cont=ind_contingency(:,:,:,sub,con);
            [theta_est, theta_err, LLF, ctable_mod, ctable_fit, psyc_mate, d0, sivals] = ...
                mADC_model_fit_psyc_del_2(cont, cvals, InpStructModel{mod});
            theta_est_all(sub,:,con,mod)=theta_est;
            theta_err_all(:,sub,con,mod)=theta_err;
            LLF_all(sub,con,mod)=LLF;
            ctable_mod_all{sub,con,mod}=ctable_mod;
            ctable_fit_all{sub,con,mod}=ctable_fit;
            psyc_mate_all{sub,con,mod}=psyc_mate;
            d0_all(:,sub,con,mod)=d0;
            sivals_all{sub,con,mod}=sivals;
        end
    end
    disp(sub); toc
end

clear mod sub con cont theta_est theta_err LLF ctable_mod ctable_fit psyc_mate d0 sivals
        
%% AIC

for mod = 1:length(mod_names_arr)
    AIC_all(:,:,mod) = 2*NoOfParams(mod) - 2*LLF_all(:,:,mod);
end
AIC_av=squeeze(mean(AIC_all,1));
AIC_std=squeeze(std(AIC_all,0,1))./sqrt(sub_tot);

for con=1:conditions
    sgn_pval(con)=signrank(AIC_all(:,con,1),AIC_all(:,con,2));
end
[~,~,~,~,nosigpvalsind] = multiple_comparisons_correction(sgn_pval,'Benjaminihochberg');
sgn_pval_mc=sgn_pval;
sgn_pval_mc(nosigpvalsind)=1;

%% Plotting
mrkr=['o','^','v'];
COND=Default_Conditions;
axis_vector=[765 835 765 835];
xticks_vector=(780:20:820);
yticks_vector=(780:20:820);
figure;
plot([axis_vector(1) axis_vector(2)],[axis_vector(3) axis_vector(4)],'k')
hold on
for con=1:3
    errorbar(AIC_av(con,2),AIC_av(con,1), ...
        AIC_std(con,2),AIC_std(con,2), ...
        AIC_std(con,1),AIC_std(con,1), ...
        'Marker',mrkr(con),'MarkerSize',10, ...
        'MarkerFaceColor','w','MarkerEdgeColor','k', ...
        'Color','k','CapSize',0)
    axis(axis_vector)
    xticks(xticks_vector);
    yticks(yticks_vector);
    axis square    
end
sigstar({[AIC_av(1,2)+1,AIC_av(1,2)-1], ...
    [AIC_av(2,2)+1,AIC_av(2,2)-1], ...
    [AIC_av(3,2)+1,AIC_av(3,2)-1]}, sgn_pval_mc)
h=legend('',COND{1},COND{2},COND{3},'','','');
h.FontSize=8;
legend('location','eastoutside')
