close all force; clear; clc
mainpath=pwd; addpath(pwd)
load('P123_Gen_Data45')

%% Psychometric Results
denom=squeeze(sum(ind_contingency,2));
ind_pc=zeros(locations,angles,sub_tot,conditions);
for con=1:conditions
    for sub=1:sub_tot
        for loc=1:locations
            for angl=1:length(angle_mag)
                ind_pc(loc,angl,sub,con)=ind_contingency(loc,loc,angl,sub,con)./denom(loc,angl,sub,con).*100;
            end
        end
        for loc=1:locations
            ind_pfa(loc,sub,con)=ind_contingency(5,loc,1,sub,con)./denom(5,1,sub,con).*100;
        end
    end
end

ind_avg_pc=squeeze(nanmean(ind_pc,2));
delcon_hr=ind_avg_pc(:,:,[1 2])-ind_avg_pc(:,:,[2 3]); % PC-PE; PE-PL
delcon_fa=ind_pfa(:,:,[1 2])-ind_pfa(:,:,[2 3]);
delcon_rt=ind_avg_rt(:,:,[1 2])-ind_avg_rt(:,:,[2 3]);

%% Delta-delta

HR_Ddel(1,:,:)=delcon_hr(1,:,:)-delcon_hr(3,:,:);
HR_Ddel(2,:,:)=delcon_hr(1,:,:)-nanmean(delcon_hr([2 4],:,:),1);
FA_Ddel(1,:,:)=delcon_fa(1,:,:)-delcon_fa(3,:,:);
FA_Ddel(2,:,:)=delcon_fa(1,:,:)-nanmean(delcon_fa([2 4],:,:),1);
RT_Ddel(1,:,:)=delcon_rt(1,:,:)-delcon_rt(3,:,:);
RT_Ddel(2,:,:)=delcon_rt(1,:,:)-nanmean(delcon_rt([2 4],:,:),1);

LOCS={'Cu-Ip';'Cu-Coav'};
locations=length(LOCS);
COND={'AE';'VE'};
conditions=length(COND);
for con=1:conditions
    for loc=1:locations
        p_values_hr_ddel(loc,con)=signrank(HR_Ddel(loc,:,con));
        p_values_fa_ddel(loc,con)=signrank(FA_Ddel(loc,:,con));
        p_values_rt_ddel(loc,con)=signrank(RT_Ddel(loc,:,con));
    end
end

[~,~,~,~,nosigpvalsind] = multiple_comparisons_correction(p_values_hr_ddel(:),'Benjaminihochberg');
p_val_mc_HR_Ddel=round(p_values_hr_ddel,3);
p_val_mc_HR_Ddel(nosigpvalsind)=1;
[~,~,~,~,nosigpvalsind] = multiple_comparisons_correction(p_values_fa_ddel(:),'Benjaminihochberg');
p_val_mc_FA_Ddel=round(p_values_fa_ddel,3);
p_val_mc_FA_Ddel(nosigpvalsind)=1;
[~,~,~,~,nosigpvalsind] = multiple_comparisons_correction(p_values_rt_ddel(:),'Benjaminihochberg');
p_val_mc_RT_Ddel=round(p_values_rt_ddel,3);
p_val_mc_RT_Ddel(nosigpvalsind)=1;

av_val_HR_Ddel=round(squeeze(nanmean(HR_Ddel,2)),2);
sd_val_HR_Ddel=round(squeeze(nanstd(HR_Ddel,0,2)./sqrt(sub_tot)),2);
av_val_FA_Ddel=round(squeeze(nanmean(FA_Ddel,2)),2);
sd_val_FA_Ddel=round(squeeze(nanstd(FA_Ddel,0,2)./sqrt(sub_tot)),2);
av_val_RT_Ddel=round(squeeze(nanmean(RT_Ddel,2)),2);
sd_val_RT_Ddel=round(squeeze(nanstd(RT_Ddel,0,2)./sqrt(sub_tot)),2);

%%
param_label={'\Delta HR','\Delta FA','\Delta RT'};
lnstylopts={'-','-.'};

%% Plotting Ddel HR

suptitle_string=sprintf('%s - %d Subjects', param_label{1}, sub_tot);
figure; set(gcf,'renderer','Painters', 'Position', [100 50 350 600])
for loc=1:locations
    subplot(2,1,loc)
    for con=1:conditions
        bar(con,av_val_HR_Ddel(loc,con),'FaceColor','white','EdgeColor','k','Linewidth',0.5,'LineStyle',lnstylopts{con});
        hold on;
    end
    errorbar(1:conditions,av_val_HR_Ddel(loc,:),sd_val_HR_Ddel(loc,:),'Color','k','LineStyle','None','LineWidth',0.5,'CapSize',0)
    xticks(1:conditions)
    set(gca,'xticklabel',COND,'Fontsize',8)
    ylabel(sprintf('%s - %s', param_label{1}, LOCS{loc}),'FontSize',12)
    sigstar({[0.7,1.3],[1.7,2.3]},p_val_mc_HR_Ddel(loc,:))
    axis([0 3 -15 35])
    yticks(-10:10:20)
end
suptitle(suptitle_string)

%% Plotting Ddel FA

suptitle_string=sprintf('%s - %d Subjects', param_label{2}, sub_tot);
figure; set(gcf,'renderer','Painters', 'Position', [100 50 350 600])
for loc=1:locations
    subplot(2,1,loc)
    for con=1:conditions
        bar(con,av_val_FA_Ddel(loc,con),'FaceColor','white','EdgeColor','k','Linewidth',0.5,'LineStyle',lnstylopts{con});
        hold on;
    end
    errorbar(1:conditions,av_val_FA_Ddel(loc,:),sd_val_FA_Ddel(loc,:),'Color','k','LineStyle','None','LineWidth',0.5,'CapSize',0)
    xticks(1:conditions)
    set(gca,'xticklabel',COND,'Fontsize',8)
    ylabel(sprintf('%s - %s', param_label{2}, LOCS{loc}),'FontSize',12)
    sigstar({[0.7,1.3],[1.7,2.3]},p_val_mc_FA_Ddel(loc,:))
    axis([0 3 -18 10])
    yticks(-10:5:5)
end
suptitle(suptitle_string)

%% Plotting Ddel RT

suptitle_string=sprintf('%s - %d Subjects', param_label{3}, sub_tot);
figure; set(gcf,'renderer','Painters', 'Position', [100 50 350 600])
for loc=1:locations
    subplot(2,1,loc)
    for con=1:conditions
        bar(con,av_val_RT_Ddel(loc,con),'FaceColor','white','EdgeColor','k','Linewidth',0.5,'LineStyle',lnstylopts{con});
        hold on;
    end
    errorbar(1:conditions,av_val_RT_Ddel(loc,:),sd_val_RT_Ddel(loc,:),'Color','k','LineStyle','None','LineWidth',0.5,'CapSize',0)
    xticks(1:conditions)
    set(gca,'xticklabel',COND,'Fontsize',8)
    ylabel(sprintf('%s - %s', param_label{3}, LOCS{loc}),'FontSize',12)
    sigstar({[0.7,1.3],[1.7,2.3]},p_val_mc_RT_Ddel(loc,:))
    axis([0 3 -0.35 0.25])
    yticks(-0.2:0.1:0.1)
end
suptitle(suptitle_string)
