close all force; clear; clc
mainpath=pwd; addpath(pwd)
load('P123_Gen_Data45')

%% Psychometric Results

ylabel_string={'cc bias'};
axis_vector=[0 5 0 1]; 
loc_order=[1 3 4 2];  % For plotting; Cued,Ipsi,Contra,Opposite
sub_avg_cc=squeeze(nanmean(ind_cc(loc_order,:,:),2));
sub_std_cc=squeeze(nanstd(ind_cc(loc_order,:,:),0,2))./sqrt(sub_tot);
test_an=ind_cc(loc_order,:,:);
av_val=sub_avg_cc;
sd_val=sub_std_cc;

%% Bar Plots cc

lnstylopts={'-','--',':'};
LOCS={'Cu';'Ip';'Co';'Op'};
COND=Default_Conditions;
col=hsv(locations);
suptitle_string=sprintf('%s - %d Subjects', ylabel_string{1} , sub_tot);

G1=repmat(LOCS,1,sub_tot,conditions);
G2=permute(repmat(COND,1,locations,sub_tot),[2 3 1]);
G3=permute(repmat(sub_final,1,locations,conditions),[2 1 3]);
[~,~,stats,~] = anovan(test_an(:),{G1(:),G2(:),G3(:)},'random',3, ...
    'model','interaction', 'varnames',{'Loc','Cond','Sub'});
figure; results=multcompare(stats,'Dimension',[1 2]);

%% Condition-wise Sort anova pvals
for i=1:size(results,1)
    for loc=1:locations-1
        for con=1:conditions
            if results(i,1)==loc+(con-1)*locations && results(i,2)<=con*locations
                p_values_temp(i,con)=results(i,6);
            end
        end
    end
end              
p_val_temp=p_values_temp(p_values_temp~=0);
p_values=reshape(p_values_temp(p_values_temp~=0),6,3);
p_val_mc=p_values;
p_val_mc(p_val_mc>0.05)=1;

figure;set(gcf,'renderer','Painters', 'Position', [100 50 1200 400]);
for con=1:conditions
    subplot(1,3,con)
    for loc=1:locations
        bar(loc,av_val(loc,con),'FaceColor','white','EdgeColor',col(loc_order(loc),:),'Linewidth',0.5,'LineStyle',lnstylopts{con});
        hold on;
    end
    errorbar(1:locations,av_val(:,con),sd_val(:,con),'Color','k','LineStyle','None','LineWidth',0.5,'CapSize',0)
    title(COND{con})
    yticks(0:0.2:0.6)
    xticks(1:locations)
    set(gca,'xticklabel',LOCS,'Fontsize',8)
    ylabel(ylabel_string,'FontSize',12)
    sigstar({[1,2],[1,3],[1,4],[2,3],[2,4],[3,4]},p_val_mc(:,con))
    axis(axis_vector)  
end
suptitle(suptitle_string)